Widget
======

The widget class is a base class for all widgets and not designed to be instantiated directly.

Reference
---------

.. autoclass:: toga.interface.widgets.base.Widget
   :members:
   :undoc-members:
   :inherited-members: